@@ -109,7 +109,7 @@ fn monitor_loop() {
                 }
                 .into(),
             )
-            // .stack_size(512 * 1024)
+            .stack_size(10 * 1024 * 1024)
             .spawn(move || {
                 // let local_exec = LEXEC.with(|v| Rc::clone(v));
                 let future = async {
